import { TransactionReceipt, EventLog } from 'web3-core';
import { Configuration, BlockchainDataModelEntity } from '@energyweb/utils-general';
import { IOwnershipCommitment } from './IOwnershipCommitment';
export interface ICertificateOwners {
    [address: string]: number;
}
export interface ICertificate {
    id: string;
    issuer: string;
    deviceId: string;
    energy: number;
    generationStartTime: number;
    generationEndTime: number;
    creationTime: number;
    creationBlockHash: string;
    owners?: ICertificateOwners;
}
export declare const getAllCertificateEvents: (certId: number, configuration: Configuration.Entity<any, any, any, any, any>) => Promise<EventLog[]>;
export declare class Entity extends BlockchainDataModelEntity.Entity implements ICertificate {
    isPrivate: boolean;
    deviceId: string;
    energy: number;
    generationStartTime: number;
    generationEndTime: number;
    issuer: string;
    creationTime: number;
    creationBlockHash: string;
    ownershipCommitment: IOwnershipCommitment;
    owners: ICertificateOwners;
    initialized: boolean;
    data: number[];
    constructor(id: string, configuration: Configuration.Entity, isPrivate?: boolean);
    sync(): Promise<Entity>;
    claim(amount?: number): Promise<TransactionReceipt>;
    transfer(to: string, amount?: number): Promise<TransactionReceipt | boolean>;
    revoke(): Promise<TransactionReceipt>;
    getAllCertificateEvents(): Promise<EventLog[]>;
    isOwned(byAddress?: string): boolean;
    ownedVolume(byAddress?: string): number;
    isClaimed(byAddress?: string): Promise<boolean>;
    claimedVolume(byAddress?: string): Promise<number>;
    private calculateOwnership;
}
export declare const createCertificate: (to: string, value: number, fromTime: number, toTime: number, deviceId: string, configuration: Configuration.Entity<any, any, any, any, any>, isVolumePrivate?: boolean) => Promise<Entity>;
export declare function claimCertificates(certificateIds: string[], configuration: Configuration.Entity): Promise<TransactionReceipt>;
export declare function transferCertificates(certificateIds: string[], to: string, configuration: Configuration.Entity): Promise<TransactionReceipt>;
