"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_general_1 = require("@energyweb/utils-general");
const Issuer_json_1 = __importDefault(require("../../build/contracts/Issuer.json"));
class Issuer extends utils_general_1.GeneralFunctions {
    constructor(web3, address) {
        const buildFile = Issuer_json_1.default;
        const buildFileAbi = buildFile.abi;
        super(address
            ? new web3.eth.Contract(buildFileAbi, address)
            : new web3.eth.Contract(buildFileAbi, buildFile.networks.length > 0 ? buildFile.networks[0] : null));
        this.web3 = web3;
    }
    async initialize(certificateTopic, registryAddress, owner, txParams) {
        const method = this.web3Contract.methods.initialize(certificateTopic, registryAddress, owner);
        return this.send(method, txParams);
    }
    async getAllEvents(eventFilter) {
        return this.web3Contract.getPastEvents('allEvents', this.createFilter(eventFilter));
    }
    async encodeData(_from, _to, _deviceId, txParams) {
        return this.web3Contract.methods.encodeData(_from, _to, _deviceId).call(txParams);
    }
    async decodeData(_data, txParams) {
        return this.web3Contract.methods.decodeData(_data).call(txParams);
    }
    async getIssuanceRequest(_issuanceRequestId, txParams) {
        return this.web3Contract.methods.getIssuanceRequest(_issuanceRequestId).call(txParams);
    }
    async getIssuanceRequestsForDevice(_deviceId, txParams) {
        return this.web3Contract.methods.getIssuanceRequestsForDevice(_deviceId).call(txParams);
    }
    async requestIssuance(_data, _isPrivate, txParams) {
        const method = this.web3Contract.methods.requestIssuance(_data, _isPrivate);
        return this.send(method, txParams);
    }
    async requestIssuanceFor(_data, _forAddress, _isPrivate, txParams) {
        const method = this.web3Contract.methods.requestIssuanceFor(_data, _forAddress, _isPrivate);
        return this.send(method, txParams);
    }
    async approveIssuance(_to, _requestId, _value, _validityData, txParams) {
        const method = this.web3Contract.methods.approveIssuance(_to, _requestId, _value, _validityData);
        return this.send(method, txParams);
    }
    async issue(_to, _value, _data, txParams) {
        const method = this.web3Contract.methods.issue(_to, _value, _data);
        return this.send(method, txParams);
    }
    async approveIssuancePrivate(_to, _requestId, _commitment, _validityData, txParams) {
        const method = this.web3Contract.methods.approveIssuancePrivate(_to, _requestId, _commitment, _validityData);
        return this.send(method, txParams);
    }
    async issuePrivate(_to, _commitment, _data, txParams) {
        const method = this.web3Contract.methods.issue(_to, _commitment, _data);
        return this.send(method, txParams);
    }
    async revokeRequest(_requestId, txParams) {
        const method = this.web3Contract.methods.revokeRequest(_requestId);
        return this.send(method, txParams);
    }
    async revokeCertificate(_certificateId, txParams) {
        const method = this.web3Contract.methods.revokeCertificate(_certificateId);
        return this.send(method, txParams);
    }
    async updateCommitment(_id, _previousCommitment, _commitment, txParams) {
        const method = this.web3Contract.methods.updateCommitment(_id, _previousCommitment, _commitment);
        return this.send(method, txParams);
    }
    async requestMigrateToPublic(_certificateId, _hash, txParams) {
        const method = this.web3Contract.methods.requestMigrateToPublic(_certificateId, _hash);
        return this.send(method, txParams);
    }
    async migrateToPublic(_requestId, _value, _salt, _proof, txParams) {
        const method = this.web3Contract.methods.migrateToPublic(_requestId, _value, _salt, _proof);
        return this.send(method, txParams);
    }
    async approvePrivateTransfer(_requestId, _proof, _previousCommitment, _commitment, txParams) {
        const method = this.web3Contract.methods.approvePrivateTransfer(_requestId, _proof, _previousCommitment, _commitment);
        return this.send(method, txParams);
    }
    async requestPrivateTransfer(_certificateId, _hash, txParams) {
        const method = this.web3Contract.methods.requestPrivateTransfer(_certificateId, _hash);
        return this.send(method, txParams);
    }
    async getRegistryAddress(txParams) {
        return this.web3Contract.methods.getRegistryAddress().call(txParams);
    }
    async version(txParams) {
        return this.web3Contract.methods.version().call(txParams);
    }
}
exports.Issuer = Issuer;
//# sourceMappingURL=Issuer.js.map